@@ -5,6 +5,8 @@ COLOR_BKG_TAX_LIST = COLOR_BKG_ACTIVE_INFO
 COLOR_QUEST = "#BBBBDD"
 COLOR_SOLUTION = "#BBDDBB"
 COLOR_RED_BTN = ("#000000", "#DDBBBB")
+COLOR_GREEN_BTN = ("#000000", "#BBDDBB")
+
 SG_COLOR_THEME = {'BACKGROUND': '#E0E0E2',
                   'TEXT': '#000000',
                   'INPUT': COLOR_BKG_ACTIVE_INFO,
@@ -15,6 +17,7 @@ SG_COLOR_THEME = {'BACKGROUND': '#E0E0E2',
                   'BORDER': 1, 'SLIDER_DEPTH': 0,
                   'PROGRESS_DEPTH': 0, }
 
+FILE_ENCODING = 'utf-8'
 
 WIDTH_ML = 80 # multi line field for text input
 LEN_ML_SMALL = 6
